      SUBROUTINE SMPLX2(VRINT,LEVEL,Q,P,Aim,Pin)
C     -----------------
C ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
C S. BALAC - 14 JUIN 1995
C MODIFICATION DU S.P. SMPLX3 DU PACKAGE ATKINSON.
C APPEL DE LA PROCEDURE FCNKL2 QUI DONNE L'INTEGRANT DANS LE CAS DE 
C TRIANGLES COURBES. 
C ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
C     CALCULATE THE INTEGRAL OF THE VECTOR-VALUED FUNCTION FCNKL(S,T) OF
C     LENGTH 3, DEFINED IN SUBROUTINE FCNKL, OVER THE UNIT SIMPLEX IN
C     THE PLANE.  THE INTEGRATION USES A COMPOSITE RULE OVER A UNIFORM
C     SUBDIVISION OF THE UNIT SIMPLEX.	ON EACH SUB-SIMPLEX, RULE T2:5-1
C     OF ART STROUD IS USED FOR THE INTEGRAL.  THE VARIABLE 'LEVEL' GIVES
C     THE NUMBER OF SUBDIVISIONS TO BE USED.  LEVEL=0 INDICATES THAT THE
C     ORIGINAL SIMPLEX IS TO BE THE INTEGRATION REGION.
C
C     INPUT:
C     FCNKL : THE SUBROUTINE DEFINING THE VECTOR FUNCTION OF LENGTH 3
C	      TO BE INTEGRATED.  IT MUST BE DECLARED IN AN EXTERNAL
C	      STATEMENT IN THE CALLING PROGRAM.	 THE FORM OF THE FUNCTION
C	      IS
C		   SUBROUTINE FCNKL(S,T,FN)
C	      THE VARIABLE POINT (S,T) CAN BE ASSUMED TO LAY IN THE
C	      UNIT SIMPLEX.  THE VALUE OF THE FUNCTION AT (S,T) IS TO
C	      BE RETURNED IN THE VECTOR FN OF LENGTH 3.
C     LEVEL : THE NUMBER OF LEVELS OF SUBDIVISIONS TO BE USED IN THE
C	      INTEGRATION.  THE RULE T2:5-1 WILL BE USED ON EACH OF
C	      4^LEVEL SUBDIVISIONS OF THE UNIT SIMPLEX.
C
C     OUTPUT:
C     VRINT : THE APPROXIMATE INTEGRAL IS TO BE RETURNED IN THE VECTOR
C	      VRINT OF LENGTH 3.
C
C     SUBPROGRAMS CALLED: FCNKL (USER SUPPLIED: PROBLEM DEPENDENT)
C
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      PARAMETER (ZERO=0.0D0, ONE=1.0D0, TWO=2.0D0,
     *           SR15=3.87298334620741D0)
      PARAMETER (A=.1125D0, B=(155.0D0-SR15)/2400.0D0,
     *           C=(155.0D0+SR15)/2400.0D0, T=ONE/3.0D0,
     *           R=(6.0D0-SR15)/21.0D0, S=(9.0D0+TWO*SR15)/21.0D0,
     *           U=(6.0D0+SR15)/21.0D0, V=(9.0D0-TWO*SR15)/21.0D0)
      DIMENSION SM(7), TM(7), W(7), FN(3), VRINT(3) 
      double precision P(3),Q(3,6),Aim(3),Pin(3)       
C
C     INITIALIZE.
      SM(1) = T
      TM(1) = T
      SM(2) = R
      TM(2) = R
      SM(3) = S
      TM(3) = R
      SM(4) = R
      TM(4) = S
      SM(5) = U
      TM(5) = U
      SM(6) = V
      TM(6) = U
      SM(7) = U
      TM(7) = V
      W(1) = A
      DO 10 I=1,3
	W(I+1) = B
10      W(I+4) = C
C
C     INITIALIZE VARIABLES FOR INTEGRATION LOOP.
      NF = 4**LEVEL
      NR = 2**LEVEL
      H = ONE/NR
      IF(LEVEL .GT. 0) THEN
	  DO 20 K=1,7
	    SM(K) = SM(K)/NR
20          TM(K) = TM(K)/NR
      END IF
      DO 25 L=1,3
25      VRINT(L) = ZERO
C
C     BEGIN INTEGRATION OVER NF SUB-SIMPLICES OF UNIT SIMPLEX.
      DO 40 I=1,NR
	SV = ZERO
	TV = (NR - I)*H
	SIGN = ONE
	DO 40 J=1,2*I-1
	  DO 30 K=1,7
	    CALL FCNKL2(SV+SIGN*SM(K),TV+SIGN*TM(K),FN,Q,P,Aim,Pin)
	    DO 30 L=1,3
30            VRINT(L) = VRINT(L) + W(K)*FN(L)
	  SIGN = -SIGN
	  IF(SIGN .LT. ZERO) THEN
	      SV = SV + H
	      TV = TV + H
	  ELSE
	      TV = TV - H
	  END IF
40        CONTINUE
      DO 50 L=1,3
50      VRINT(L) = VRINT(L)/NF
      RETURN
      END
